<?php
/*
==================================================
	GetField
==================================================

Returns any document field or template variable from any document or any of its parents.

Author: Grzegorz Adamiak [grad]
Version: 1.3 beta @2006-11-08 14:40:04
License: LGPL
MODx: 0.9.2.1+

See GetField.txt for instructions and version history.
--------------------------------------------------
*/

unset($docid, $field, $parent, $parentLevel, $topid);

# GetField functions
# ---------------------------------------------

# gfGetFieldContent
# Returns the inherited value of any content field
if (!function_exists(gfGetFieldContent))
{
	function gfGetFieldContent($modx,$gfIntDocId=0,$gfStrDocField)
	{
		if(empty($gfIntDocId)) return 'error1';
		
		$resource = $modx->getDocumentObject('id',$gfIntDocId);
		$output = $resource[$gfStrDocField];
		if(is_array($output)) $output = $modx->getTemplateVarOutput($gfStrDocField,$gfIntDocId);
		
		if(substr($output,0,8) === '@INHERIT')
		{
			$output = gfGetFieldContent($modx,$resource['parent'],$gfStrDocField);
		}
		return $output;
	}
}

# gfGetParentId
# Returns the parent document ID
if (!function_exists(gfGetParentId))
{
	function gfGetParentId($modx, $gfIntDocId, $gfIntTopDocId, $gfIntParentLevel)
	{
		if(empty($gfIntDocId)) return 'error2';
		
		# build an array of document ancestors IDs
		$gfArrParentIds = array (); // initialize;
		$gfArrParentIds[] = $gfIntDocId; // add the specified document ID on first place
		
		// get IDs of all parents back to root of the document tree
		while (($gfArrParent = $modx->getDocument($gfIntDocId,'parent')) && ($gfArrParent['parent'] != 0))
		{
			$gfIntDocId = $gfArrParent['parent']; // move up one document in the document tree
			$gfArrParentIds[] = $gfIntDocId; // add parent ID to the array
		}
		unset($gfIntDocId, $gfArrParent);
		
		$gfIntParentsCount = count($gfArrParentIds); // number of the parents
		
		// determine the ID of the specified parent
		switch ($gfIntTopDocId)
		{
			case 0: // not set or set to the root of the document tree
				if($gfIntParentLevel < $gfIntParentsCount)
					$gfIntDocId = $gfArrParentIds[$gfIntParentLevel];// find parent in specified levels up
				else
					$gfIntDocId = $gfArrParentIds[$gfIntParentsCount - 1];// if not set return the topmost (ultimate) parent
				break;
			default: // set to any other document
				$gfIntParentKey = array_search($gfIntTopDocId, $gfArrParentIds); // find the index of parent
				switch ($gfIntParentKey)
				{
					case 0: // not an ancestor or the document itself
						$gfIntDocId = 0;
						break;
					default: // parent is above the document in document tree
						if($gfIntParentLevel && ($gfIntParentLevel < $gfIntParentKey))
							$gfIntDocId = $gfArrParentIds[$gfIntParentLevel]; // find parent in specified levels up
						else
							$gfIntDocId = $gfArrParentIds[$gfIntParentKey - 1];
				}
		} // end switch
		unset($gfIntTopDocId, $gfIntParentLevel, $gfIntParentsCount, $gfIntParentKey, $gfArrParentIds);
		return $gfIntDocId;
	}
}
